#
# spec file for package netgen
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%bcond_without need_clang
%bcond_with openmpi
%bcond_without ffmpeg
%if 0%{?suse_version} <= 1320
%bcond_without python
%else
%bcond_without python
%endif

Name:           netgen
Version:        6.0.99+git20170127.1908
Release:        2.1
Summary:        Automatic 3D tetrahedral mesh generator
License:        GPL-3.0+
Group:          Productivity/Graphics/CAD
Url:            https://sourceforge.net/projects/netgen-mesher/
Source0:        netgen.tar.xz
Source1:        pybind.tar.xz
Source2:        0001-Fixes-to-build-on-openSUSE-Packman.patch
BuildRequires:  OpenCASCADE-devel
BuildRequires:  cmake
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(tcl)
BuildRequires:  pkgconfig(tk)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  libjpeg-devel
BuildRequires:  openCOLLADA-devel
%if %{with python}
BuildRequires:  python3-devel
%endif
%if %{with openmpi}
BuildRequires:  openmpi-devel
BuildRequires:  metis-devel
%endif
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat) 
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
%endif
%if %{with need_clang}
BuildRequires:  llvm-clang
BuildRequires:  llvm
%else
BuildRequires:  gcc
BuildRequires:  gcc-c++
%endif
BuildRequires:  xz
# Required for 13.2




BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
NETGEN is an automatic 3d tetrahedral mesh generator. It accepts input from constructive solid geometry (CSG) or boundary representation (BRep) from STL file format. The connection to a geometry kernel allows the handling of IGES and STEP files. NETGEN contains modules for mesh optimization and hierarchical mesh refinement. Netgen is open source based on the LGPL license. It is available for Unix/Linux and Windows.

%package devel
Summary:        Development files for netgen
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       OpenCASCADE-devel

%description devel
Development files for NETGEN.


%prep
%setup -q -n netgen
%if %{with python}
  # export pybind11 headers
  pushd external_dependencies/pybind11/
    xz -dc %{S:1} | tar xf -
  popd
%endif
patch --merge -p1 < %{S:2}

%build
mkdir build
cd build
%if %{with need_clang}
  CFLAGS="$(echo %{optflags} | sed "s:-grecord-gcc-switches::g")" \
  CXXFLAGS="$(echo %{optflags} | sed "s:-grecord-gcc-switches::g")" \
%else
  CFLAGS="%{optflags}" \
  CXXFLAGS="%{optflags}" \
%endif
  cmake \
    -DINSTALL_DIR=%{_prefix} \
    -DBINDIR=%{_bindir} \
    -DDATADIR=%{_datadir}/netgen \
    -DDOCDIR=%{_docdir}/netgen \
    -DINCLUDEDIR=%{_includedir}/netgen \
    -DLIBDIR=%{_libdir}/netgen \
    -DCMAKE_SKIP_BUILD_RPATH=ON \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
%if %{with need_clang}
    -DCMAKE_C_COMPILER=clang \
    -DCMAKE_CXX_COMPILER=clang++ \
%if 0%{?suse_version} > 1320
    -DCMAKE_AR=%{_bindir}/llvm-ar \
    -DCMAKE_RANLIB=%{_bindir}/llvm-ranlib \
    -DCMAKE_NM=%{_bindir}/llvm-nm \
    -DCMAKE_OBJDUMP=%{_bindir}/llvm-objdump \
%endif
%endif
    -DUSE_NATIVE_ARCH=OFF \
    -DUSE_GUI=ON \
%if %{with python}
    -DUSE_PYTHON=ON \
%else
    -DUSE_PYTHON=OFF \
%endif
%if %{with openmpi}
    -DUSE_MPI=ON \
%else
    -DUSE_MPI=OFF \
%endif
    -DUSE_OCC=ON \
    -DUSE_JPEG=ON \
%if %{with ffmpeg}
    -DUSE_MPEG=ON \
%else
    -DUSE_MPEG=OFF \
%endif
    ..
  make %{?_smp_mflags}
cd ..

%install
cd build
  make DESTDIR=%{buildroot} install %{?_smp_mflags}
cd ..

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/netgen
%{_datadir}/netgen
%{_docdir}/netgen
%{_libdir}/netgen
%if %{with python}
%{python3_sitearch}/netgen
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/netgen
%{_datadir}/cmake/Modules/*

%changelog
* Sun May 22 2016 johannesobermayr@gmx.de
- initial package
